@@ -269,6 +269,15 @@ extern "C" int slb_kbd_backlight_get(uint32_t model, uint32_t* color);
 /* Gets keyboard backlight color. Set model to 0 to guess it */
 extern "C" int slb_kbd_backlight_set(uint32_t model, uint32_t color);
 
+/* Sets keyboard backlight brightness. Set model to 0 to guess it */
+extern "C" int slb_kbd_brightness_get(uint32_t model, uint32_t* brightness);
+
+/* Gets keyboard backlight brightness. Set model to 0 to guess it */
+extern "C" int slb_kbd_brightness_set(uint32_t model, uint32_t brightness);
+
+/* Gets maximum brightness value */
+extern "C" int slb_kbd_brightness_max(uint32_t model, uint32_t* max);
+
 /* Loads configuration from disk to driver. ie: backlight color */
 extern "C" int slb_config_load(uint32_t model);
 
@@ -319,3 +328,10 @@ extern "C" int slb_qc71_profile_get(uint32_t* value);
 
 /* Sets profile */
 extern "C" int slb_qc71_profile_set(uint32_t value);
+
+/* Gets custom TDP */
+extern "C" int slb_qc71_custom_tdp_get(uint32_t* pl1, uint32_t* pl2, uint32_t* pl4);
+
+/* Sets custom TDP */
+extern "C" int slb_qc71_custom_tdp_set(uint32_t pl1, uint32_t pl2, uint32_t pl4);
+
